@@ -125,10 +125,20 @@ class LibRepo:
         libs = []
         if not arch and not build:
             for b in available_build_names():
+                lib = LibData(name=name, version=ver, platform=platform, arch=None, build=b)
+                if self.exist(lib):
+                    libs.append(lib)
+
                 for p in available_arches(platform):
                     lib = LibData(name=name, version=ver, platform=platform, arch=p, build=b)
                     if self.exist(lib):
                         libs.append(lib)
+
+            for p in available_arches(platform):
+                lib = LibData(name=name, version=ver, platform=platform, arch=p, build=None)
+                if self.exist(lib):
+                    libs.append(lib)
+                    
         if arch and not build:
             for b in available_build_names():
                 lib = LibData(name=name, version=ver, platform=platform, arch=arch, build=b)
